( cd usr/doc/rdist ; rm -rf README )
( cd usr/doc/rdist ; ln -sf /cdrom/live/usr/doc/rdist/README README )
( cd usr/bin ; rm -rf rdist )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/rdist rdist )
( cd usr/bin ; rm -rf rdistd )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/rdistd rdistd )
( cd usr/man/preformat/cat1 ; rm -rf rdist.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/rdist.1.gz rdist.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf rdistd.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/rdistd.1.gz rdistd.1.gz )
